Module: Nitrocop
- Defined in:
- lib/nitrocop.rb
Constant Summary collapse
- VERSION =
"0.0.1.pre12"
Class Method Summary collapse
-
.executable ⇒ Object
Returns the path to the precompiled nitrocop binary, or nil if no binary is bundled (e.g. the base/fallback gem on an unsupported platform).
Class Method Details
.executable ⇒ Object
Returns the path to the precompiled nitrocop binary, or nil if no binary is bundled (e.g. the base/fallback gem on an unsupported platform).
8 9 10 11 |
# File 'lib/nitrocop.rb', line 8 def self.executable bin = File.("../libexec/nitrocop", __dir__) bin if File.file?(bin) && File.executable?(bin) end |